#        Name : tool.rb
# Description : 
#      Author : Didier Bur
#       Usage : 
#        Date : 11.2005
#        Type : geometric tools set

require 'sketchup.rb'
require 'parametric.rb'


#-----------------------------------------------------------------------------------------------------
#                                        PROJECTION FUNCTIONS
#-----------------------------------------------------------------------------------------------------

# --------------------------------------------------- zeigt die aktuellen shortcuts an


 

#----------------------------------------------------fortlaufende Nummern

class Numb

# initialize on tool activation
def activate
   @ip = Sketchup::InputPoint.new
   @iptemp = Sketchup::InputPoint.new
   @displayed = false
   @number = 1
   @increment = 1
end

# on MouseMove display InputPoint and update VCB
def onMouseMove(flags, x, y, view)
   # show VCB and status info
   Sketchup::set_status_text("Numb::Click to insert text", SB_PROMPT)
   Sketchup::set_status_text("Number", SB_VCB_LABEL)
   Sketchup::set_status_text("#{@number}", SB_VCB_VALUE)
   
   # get position in the model
   @iptemp.pick view, x, y

   if( @iptemp.valid? )
      changed = @iptemp != @ip
      @ip.copy! @iptemp
      
      @pos = @ip.position;
      
      # view update? 
      if( changed and (@ip.display? or @displayed) ) 
         view.invalidate
      end
   end
end

# on left click add text
def onLButtonDown(flags, x, y, view)
   # add text
   Sketchup.active_model.entities.add_text(@number.to_s, @pos)
   @number = @number + @increment
end

# on right click add text
def onRButtonDown(flags, x, y, view)
   # display input dialog (inputbox needs array)   
   result = inputbox ["Increment value"],[@increment]
   return if not result
   @increment = result[0]
end

# on user text in VCB modify number to be displayed
def onUserText(text,view)
   begin
      value = text.to_i
      rescue
      # Error parsing the text
      UI.beep
      value = nil
      Sketchup::set_status_text "", SB_VCB_VALUE
   end
   return if !value
   
   @number = value
end

# update the view
def draw(view)
   if( @ip.valid? && @ip.display? )
      @ip.draw view
      @displayed = true
   else
      @displayed = false
   end
end

end # class Numb

#---------------------------------------------------------------Bewegen, Drehen...von Komponenten

module JF
   module Mover
      Version = 1.1
      def self.create
	 dlg = UI::WebDialog.new "Mover", false, "Mover", 200,200,100,100,true
	 dlg.set_file File.join(JF::HOME, "mover", "mover.html")
	 @cb = "false"
	 #dlg.set_position 50, 50
	 dlg.show {}

	 dlg.add_action_callback("sealevel") { |d,params|
	    Sketchup.active_model.selection.each { |e|
	       tr = e.transformation
	       pt = tr.origin
	       pt = [0, 0, -pt.z]
	       tr = Geom::Transformation.new pt
	       if e.respond_to?("transform!")
		  e.transform! tr
	       end
	    }
	 }

	 dlg.add_action_callback("checkbox_state") { |d, params|
	    #p params
	    @cb = params
	 }

	 dlg.add_action_callback("rotate") { |d, p|
	    angle = d.get_element_value("angle").to_i
	    angle = p.to_i if p
	    bb = Sketchup.active_model.selection[0].bounds
	    tr = Geom::Transformation.rotation(bb.center, [0, 0, 1], -angle.degrees)
	    Sketchup.active_model.selection[0].transform! tr
	 }

	 dlg.add_action_callback("move") do |d, params|
	    Sketchup.active_model.start_operation("Mover")
	    amt = d.get_element_value("move_amt")
	    flag = false
	    if amt["%"]
	       amt.delete!("%")
	       flag = true
	    else
	    amt = amt.to_l
	    end
	    Sketchup.active_model.selection.each { |e|
	       bb = e.bounds
	       x = y = z = 0
	       case params
	       when "n"
		  y = amt
		  y = bb.height if amt == 0
	       when "ne"
		  x = y = amt
		  if amt == 0
		     x = bb.width
		     y = bb.height
		  end
	       when "e"
		  x = amt
		  x = bb.width if amt == 0.0
	       when "se"
		  x = amt
		  y = -amt
		  if amt == 0
		     x = bb.width
		     y = -bb.height
		  end
	       when "s"
		  y = -amt
		  y = -bb.height if amt == 0.0
	       when "sw"
		  y = -amt
		  x = -amt
		  if amt == 0
		     y = -bb.height
		     x = -bb.width
		  end

	       when "w"
		  x = -amt
		  x = -bb.width if amt == 0.0
	       when "nw"
		  y = amt
		  x = -amt
		  if amt == 0
		     y = bb.height
		     x = -bb.width
		  end
	       when "u"
		  z = amt
		  z = bb.depth if amt == 0.0
	       when "d"
		  z = -amt
		  z = -bb.depth if amt == 0.0
	       when "o"
		  x = y = z = 0
		  e.transformation = [0,0,0]
	       end
	       pt = [x, y, z]
	       tr = Geom::Transformation.new pt
	       if @cb == "false" # move, no copy
		  e.transform! tr if e.respond_to?("transform!")
	       else # copy
		  if e.typename == "ComponentInstance" 
		     ins = e.definition
		     e1 = Sketchup.active_model.active_entities.add_instance ins, e.transformation
		     e1.material = e.material
		  else
		     e1 = e.copy
		     e1.material = e.material
		  end
		  e.transform! tr if e.respond_to?("transform!")
	       end
	    }
	    Sketchup.active_model.commit_operation
	 end # move call_back

	 dlg.add_action_callback("find_wall") { |d, p|
	    m=Sketchup.active_model
	    bb=m.selection[0].bounds
	    c=bb.center
	    #m.entities.add_cpoint c
	    st = [c.x, c.y + bb.height/2+1, c.z]
	    st1 = [c.x, c.y + bb.height/2, c.z]
	    ray = [st, Geom::Vector3d.new(0, 1, 0)]
	    res = m.raytest ray
	    p2 = res[1][-1].bounds.center
	    p1 = res[0]
	    #m.entities.add_edges st, p1
	    v = p1 - st1
	    m.selection[0].transform! v
	 }

	 dlg.add_action_callback("find_center") {|d, p|
	    #m = Sketchup.active_model
	    #bb = m.selection[0].bounds
	    #m.selection.clear
	    #c = bb.center
	    #st = [c.x+1, c.y, c.z - bb.depth/2]
	    #m.entities.add_cline c, st
	    #ray = [st, Geom::Vector3d.new(0, 0, -1)]
	    #res = m.raytest ray
	    #t = []
	    #t  << res[1] if res
	    #ray = [st, Geom::Vector3d.new(0, 0, 1)]
	    #res = m.raytest ray
	    #t <<  res[1] if res
	    #t.flatten!
	    #p t
	    #m.selection.add t
	 }
	 dlg.add_action_callback("keys") { |d, a|
	    p "keys:"
	    p a
	 }

      end # def create

   end # module Mover

  

end # module JF

#-------------------------------------------------------------Rechner


